"use strict";
/*
 * Deepkit Framework
 * Copyright (C) 2020 Deepkit UG
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeAction = void 0;
const core_1 = require("@deepkit/core");
const type_1 = require("@deepkit/type");
const core_2 = require("./core");
async function executeAction(actionTypes, controllerName, controllerInstance, methodName, args) {
    for (const [i, p] of core_1.eachPair(actionTypes.parameters)) {
        if (!p.typeSet && p.type === 'any' && args[i] && args[i].constructor === Object) {
            throw new Error(`${controllerName}::${methodName} argument ${i} is an Object with unknown structure. Please declare the type using the @f decorator.`);
        }
        const errors = [];
        type_1.jitValidateProperty(p)(args[i], methodName + '#' + String(i), errors);
        if (errors.length > 0) {
            throw new core_2.ValidationParameterError(controllerName, methodName, i, errors.map(error => new core_2.ValidationErrorItem(error.path, error.message, error.code)));
        }
        args[i] = type_1.jsonSerializer.deserializeProperty(p, args[i]);
    }
    let result = controllerInstance[methodName](...args);
    if (core_1.isPromise(result)) {
        result = await result;
    }
    const schema = type_1.getClassSchema(controllerInstance.constructor);
    if (schema.hasMethod(methodName)) {
        return {
            value: result,
            encoding: schema.getMethod(methodName),
        };
    }
    const p = new type_1.PropertySchema(methodName);
    if (result) {
        p.setFromJSValue(result);
    }
    return {
        value: result,
        encoding: p,
    };
}
exports.executeAction = executeAction;
//# sourceMappingURL=action.js.map