"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("jest-extended");
require("reflect-metadata");
const index_1 = require("../index");
const core_1 = require("@deepkit/core");
const rxjs_1 = require("rxjs");
function assert() {
}
test('test teardown', async () => {
    {
        let tearDownCalled = false;
        const subject = new rxjs_1.Subject();
        subject.subscribe({ error: () => { } }).add(() => {
            tearDownCalled = true;
        });
        subject.complete();
        expect(tearDownCalled).toBe(true);
        expect(subject.closed).toBe(false);
        subject.unsubscribe();
        expect(subject.closed).toBe(true);
    }
    {
        let tearDownCalled = false;
        const subject = new rxjs_1.Subject();
        subject.subscribe({ error: () => { } }).add(() => {
            tearDownCalled = true;
        });
        subject.error('asd');
        expect(subject.closed).toBe(false);
        expect(tearDownCalled).toBe(true);
        subject.unsubscribe();
        expect(subject.closed).toBe(true);
        await core_1.sleep(1);
    }
});
test('test decayed error', async () => {
    async function doIt() {
        return new Promise((resolve, reject) => {
            setTimeout(() => {
                reject('Ciao');
            }, 100);
        });
    }
    doIt().catch(() => { });
    await core_1.sleep(0.2);
});
test('test error subject', async () => {
    {
        let gotError;
        try {
            const subject = new rxjs_1.Subject();
            subject.subscribe(() => {
            }, (error) => {
                gotError = error;
            });
            subject.subscribe({ error: () => { } });
            subject.error('My Error');
            subject.unsubscribe();
            await core_1.sleep(1);
        }
        catch (error) { }
    }
});
test('test root/child', async () => {
    const root = new rxjs_1.BehaviorSubject('');
    const child2 = new rxjs_1.BehaviorSubject('');
    const sub2 = root.subscribe((next) => {
        console.log('nextd', next);
        try {
            child2.next(next);
        }
        catch (error) {
            sub2.unsubscribe();
            console.log('sub2 forward error', error);
        }
    }, (error) => {
        child2.error(error);
        console.log('sub2 error', error);
    }, () => {
        child2.complete();
        console.log('sub2 complete');
    });
    child2.unsubscribe();
    console.log('root next 1');
    root.next('asd 1');
    console.log('root next 2');
    root.next('asd 2');
    console.log('root next 3');
    root.next('asd 3');
});
test('test FilterQuery', async () => {
    assert();
    assert();
    function doIt(query) {
    }
    doIt({ id: '333' });
    function get(classType, filter) {
    }
    doIt({ id: '123' });
    doIt({ $or: [{ id: '123' }, { id: '2333' }] });
    doIt({ id: { $in: ['123', '2333'] } });
});
test('test StreamBehaviorSubject', async () => {
    let teardownCalled = false;
    const subject = new index_1.StreamBehaviorSubject(undefined, () => {
        teardownCalled = true;
    });
    await subject.unsubscribe();
    expect(teardownCalled).toBe(true);
});
test('test StreamBehaviorSubject fork', async () => {
    let rootTeardownCalled = false;
    const subject = new index_1.StreamBehaviorSubject(undefined, () => {
        rootTeardownCalled = true;
    });
    let forkTeardownCalled = false;
    const fork = new index_1.StreamBehaviorSubject(undefined, () => {
        forkTeardownCalled = true;
    });
    subject.subscribe(fork);
    expect(rootTeardownCalled).toBe(false);
    expect(forkTeardownCalled).toBe(false);
    await fork.unsubscribe();
    expect(rootTeardownCalled).toBe(false);
    expect(forkTeardownCalled).toBe(true);
    await subject.unsubscribe();
    expect(rootTeardownCalled).toBe(true);
    expect(forkTeardownCalled).toBe(true);
});
//# sourceMappingURL=core.spec.js.map